@@ -127,7 +127,7 @@ pub(crate) unsafe fn from_libusb(config: *const libusb_config_descriptor) -> Con
 
 #[cfg(test)]
 mod test {
-    use std::mem;
+    use std::mem::ManuallyDrop;
 
     // The Drop trait impl calls libusb_free_config_descriptor(), which would attempt to free
     // unallocated memory for a stack-allocated config descriptor. Allocating a config descriptor
@@ -137,9 +137,8 @@ mod test {
     // as `$config` should be stack-allocated to prevent memory leaks in the test suite.
     macro_rules! with_config {
         ($name:ident : $config:expr => $body:block) => {{
-            let $name = unsafe { super::from_libusb(&$config) };
+            let $name = ManuallyDrop::new(unsafe { super::from_libusb(&$config) });
             $body;
-            mem::forget($name);
         }};
     }
 
